"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_codegen_core_1 = require("graphql-codegen-core");
var fs = require("fs");
var path = require("path");
var document_finder_1 = require("../../utils/document-finder");
var errors_1 = require("../../errors");
exports.graphQLExtensions = ['.graphql', '.graphqls', '.gql'];
exports.loadFileContent = function (filePath) {
    if (fs.existsSync(filePath)) {
        var fileContent = fs.readFileSync(filePath, 'utf8');
        var fileExt = path.extname(filePath);
        if (exports.graphQLExtensions.includes(fileExt)) {
            return graphql_codegen_core_1.parse(new graphql_codegen_core_1.Source(fileContent, filePath));
        }
        var foundDoc = document_finder_1.extractDocumentStringFromCodeFile(fileContent);
        if (foundDoc) {
            return graphql_codegen_core_1.parse(new graphql_codegen_core_1.Source(foundDoc, filePath));
        }
        else {
            return null;
        }
    }
    else {
        throw new errors_1.DetailedError("\n\n      Failed to load a document.\n      Document file " + filePath + " does not exists.\n\n    ");
    }
};
exports.loadDocumentsSources = function (filePaths) {
    return filePaths.map(function (filePath) { return ({ filePath: filePath, content: exports.loadFileContent(filePath) }); }).filter(function (result) { return result.content; });
};
//# sourceMappingURL=document-loader.js.map